#
# spec file for package python-sortedcollections
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-sortedcollections
Version:        2.1.0
Release:        2.6
Summary:        Python Sorted Collections
License:        Apache-2.0
Group:          Development/Languages/Python
URL:            https://github.com/grantjenks/sortedcollections
#Source:         https://files.pythonhosted.org/packages/source/s/sortedcollections/sortedcollections-%%{version}.tar.gz
Source:         https://github.com/grantjenks/python-sortedcollections/archive/v%{version}.tar.gz
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-sortedcontainers >= 2
BuildArch:      noarch
# SECTION test requirements
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module sortedcontainers >= 2}
# /SECTION
%python_subpackages

%description
SortedCollections is an Python sorted collections library.

Features
--------

- ValueSortedDict - Dictionary with (key, value) item pairs sorted by value.
- ItemSortedDict - Dictionary with key-function support for item pairs.
- OrderedDict - Ordered dictionary with numeric indexing support.
- OrderedSet - Ordered set with numeric indexing support.
- IndexableDict - Dictionary with numeric indexing support.
- IndexableSet - Set with numeric indexing support.
- SegmentList - List with fast random access insertion and deletion.

%prep
%setup -q -n python-sortedcollections-%{version}
rm tox.ini

%build
%python_build

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
%pytest tests

%files %{python_files}
%doc README.rst
%license LICENSE
%{python_sitelib}/*

%changelog
* Fri Dec  1 2023 Antonio Larrosa <alarrosa@suse.com>
- Add %%{?sle15_python_module_pythons}
* Sat Jan 30 2021 John Vandenberg <jayvdb@gmail.com>
- Update to v2.1.0
  * Add NearestDict
  * Update for Python 3
  * Fixes for doctest support
  * Add NearestDict implementation
  * Update docs to reference NearestDict
  * Use Python3 defaults for inheritance
  * Use f-strings
- from v2.0.0
  * Remove shims for Python 2
  * Add support for mypy
  * Drop need for "gj" from requirements
  * Load version from __init__.py rather than by import
  * Add __all__ to __init__.py for flake8
  * Small fixes/changes for linters/formatters/type-checkers
- from v1.2.3
  * Add support for "blue" formatter
  * Fixes for doctest support
- from v1.2.2
  * Add pickle support for IndexableSet
* Wed Jul 22 2020 Matej Cepl <mcepl@suse.com>
- Update to 1.2.1:
  - Update self._dict_* methods to use dict.__* functions directly.
* Mon Jul 20 2020 Matej Cepl <mcepl@suse.com>
- Add method_item.patch to replace _del_item and _set_item methods
  (gh#grantjenks/python-sortedcollections#12).
* Tue May 14 2019 Marketa Calabkova <mcalabkova@suse.com>
- update to version 1.1.2
  * Add ItemSortedDict.__deepcopy__ for deep copying
  * Define _setitem = __setitem__ in overrides
  * Some new tests and various code cleanup
* Tue Dec  4 2018 Matej Cepl <mcepl@suse.com>
- Remove superfluous devel dependency for noarch package
* Thu May 24 2018 toddrme2178@gmail.com
- Update to 1.0.1
  * Update for sortedcontainers V2 and Python 3 semantics
  * Update sortedcollections to remove load (changed in sortedcontainers)
- Fix changes file name
* Mon Aug 14 2017 toddrme2178@gmail.com
- Initial version
